@@ -1,6 +1,6 @@
 import logging
 
-from typing import Optional, Dict, Any, Tuple, List, Union, Callable
+from typing import Optional, Dict, Any, Tuple, List, Union, Callable, Type
 from os import environ, path
 from hashlib import sha1 as sha1_hash
 from dataclasses import dataclass, field
@@ -19,7 +19,7 @@ logger = logging.getLogger(__name__)
 
 
 # @TODO: these two classes is needed here to avoid circular imports
-class GrizzlyTasksBase(SequentialTaskSet):
+class GrizzlyScenarioBase(SequentialTaskSet):
     pass
 
 
@@ -27,7 +27,7 @@ class GrizzlyTasksBase(SequentialTaskSet):
 class GrizzlyTask(metaclass=ABCMeta):
     scenario: 'GrizzlyContextScenario' = field(init=False, repr=False)
 
-    def implementation(self) -> Callable[[GrizzlyTasksBase], Any]:
+    def implementation(self) -> Callable[[GrizzlyScenarioBase], Any]:
         raise NotImplementedError(f'{self.__class__.__name__} has not implemented "implementation"')
 
 
@@ -117,7 +117,7 @@ class GrizzlyContextScenario:
     wait: GrizzlyContextScenarioWait = field(init=False, repr=False, hash=False, compare=False, default_factory=GrizzlyContextScenarioWait)
     tasks: List[GrizzlyTask] = field(init=False, repr=False, hash=False, compare=False, default_factory=list)
     validation: GrizzlyContextScenarioValidation = field(init=False, hash=False, compare=False, default_factory=GrizzlyContextScenarioValidation)
-    stop_on_failure: bool = field(init=False, default=False)
+    failure_exception: Optional[Type[Exception]] = field(init=False, default=None)
     orphan_templates: List[str] = field(init=False, repr=False, hash=False, compare=False, default_factory=list)
 
     @property
